==> saravieira-market-0.0.0.tgz: package/cloud/index.js <==
import React, { useRef, useMemo } from 'react';
import { useFrame } from '@react-three/fiber';
import { useTexture, Billboard } from '@react-three/drei';

const Cloud = ({
  size = 1,
  opacity = 0.5,
  speed = 0.4,
  spread = 10,
  length = 1.5,
  segments = 20,
  dir = 1,
  ...props
}) => {
  const group = useRef();
  const texture = useTexture('/cloud.png');
  const clouds = useMemo(() => [...new Array(segments)].map((_, index) => ({
    x: spread / 2 - Math.random() * spread,
    y: spread / 2 - Math.random() * spread,
    scale: 0.4 + Math.sin((index + 1) / segments * Math.PI) * ((0.2 + Math.random()) * 10) * size,
    density: Math.max(0.2, Math.random()),
    rotation: Math.max(0.002, 0.005 * Math.random()) * speed
  })), [spread, segments, speed, size]);
  useFrame(state => {
    var _group$current;

    return (_group$current = group.current) == null ? void 0 : _group$current.children.forEach((cloud, index) => {
      cloud.rotation.z += clouds[index].rotation * dir;
      cloud.scale.setScalar(clouds[index].scale + (1 + Math.sin(state.clock.getElapsedTime() / 10)) / 2 * index / 10);
    });
  });
  return /*#__PURE__*/React.createElement("group", props, /*#__PURE__*/React.createElement("group", {
    position: [0, 0, segments / 2 * length],
    ref: group
  }, clouds.map(({
    x,
    y,
    scale,
    density
  }, index) => /*#__PURE__*/React.createElement(Billboard, {
    key: index,
    scale: [scale, scale, scale],
    position: [x, y, -index * length],
    lockZ: true
  }, /*#__PURE__*/React.createElement("meshStandardMaterial", {
    map: texture,
    transparent: true,
    opacity: scale / 6 * density * opacity,
    depthTest: false
  })))));
};

export { Cloud };

==> saravieira-market-0.0.1.tgz: package/cloud/index.js <==
import React, { useRef, useMemo } from 'react';
import { useFrame } from '@react-three/fiber';
import { useTexture, Billboard } from '@react-three/drei';

const Cloud = ({
  size = 1,
  opacity = 0.5,
  speed = 0.4,
  spread = 10,
  length = 1.5,
  segments = 20,
  dir = 1,
  ...props
}) => {
  const group = useRef();
  const texture = useTexture('https://market-assets.fra1.cdn.digitaloceanspaces.com/market-assets/components/src/cloud/cloud.png');
  const clouds = useMemo(() => [...new Array(segments)].map((_, index) => ({
    x: spread / 2 - Math.random() * spread,
    y: spread / 2 - Math.random() * spread,
    scale: 0.4 + Math.sin((index + 1) / segments * Math.PI) * ((0.2 + Math.random()) * 10) * size,
    density: Math.max(0.2, Math.random()),
    rotation: Math.max(0.002, 0.005 * Math.random()) * speed
  })), [spread, segments, speed, size]);
  useFrame(state => {
    var _group$current;

    return (_group$current = group.current) == null ? void 0 : _group$current.children.forEach((cloud, index) => {
      cloud.rotation.z += clouds[index].rotation * dir;
      cloud.scale.setScalar(clouds[index].scale + (1 + Math.sin(state.clock.getElapsedTime() / 10)) / 2 * index / 10);
    });
  });
  return /*#__PURE__*/React.createElement("group", props, /*#__PURE__*/React.createElement("group", {
    position: [0, 0, segments / 2 * length],
    ref: group
  }, clouds.map(({
    x,
    y,
    scale,
    density
  }, index) => /*#__PURE__*/React.createElement(Billboard, {
    key: index,
    scale: [scale, scale, scale],
    position: [x, y, -index * length],
    lockZ: true
  }, /*#__PURE__*/React.createElement("meshStandardMaterial", {
    map: texture,
    transparent: true,
    opacity: scale / 6 * density * opacity,
    depthTest: false
  })))));
};

export { Cloud };
